@@ -92,12 +92,16 @@ class ClientProxy(WebsocketConsumer):
                 "notebook_id": self.notebook_id,
                 "session_id": self.session_id,
                 "worker_id": worker.id,
+                #
+                # ugly hack for docker deployment
+                #
                 "server_url": self.server_address
+                if "0.0.0.0" not in self.server_address
+                else self.server_address + ":9000",
             }
             transaction.on_commit(lambda: task_start_websocket_worker.delay(job_params))
 
     def worker_ping(self):
-
         workers = Worker.objects.filter(
             Q(state="Running") | Q(state="Queued") | Q(state="Busy"),
             session_id=self.session_id,
@@ -126,6 +130,7 @@ class ClientProxy(WebsocketConsumer):
 
         # clear stale workers
         workers = Worker.objects.filter(
-            updated_at__lte=timezone.now() - timedelta(minutes=settings.WORKER_STALE_TIME)
+            updated_at__lte=timezone.now()
+            - timedelta(minutes=settings.WORKER_STALE_TIME)
         )
         workers.delete()
